c        ***********************************************************
c        *
c        * cxpXsec:  get xsection for proton  target.
c        *
c
        subroutine cxpXsec(pj, xs)
        implicit none

#include  "Zcode.h"
#include  "Zptcl.h"

        record /ptcl/ pj
        real*8  xs, ke
        integer k
c

        character*80 msg



         k=pj.code
         ke = pj.fm.p(4) - pj.mass
c

         if(k .eq. kpion .or. k .eq. keta) then
            if(pj.charge .ge. 0) then
               call cpiPluspXsec(ke, xs)
            else
               call cpiMinuspXsec(ke, xs)
            endif
         elseif(k .eq. kkaon ) then
            if(pj.charge .ge. 0.) then
               call ckPluspXsec(ke, xs)
            else
               call ckMinuspXsec(ke, xs)
            endif
         elseif(k .eq. knuc) then
            if(pj.charge .ge. 0.) then
               call cppXsec(ke, xs)
            else
               call cpbarpXsec(ke, xs)
            endif
         elseif(k .eq. krho  .or. k .eq. komega  
     *         .or. k .eq. kphi) then
            if(pj.charge .ge. 0) then
               call cpiPluspXsec(ke, xs)
            else
               call cpiMinuspXsec(ke, xs)
            endif
         else
               write(msg,*) ' undef.ptcl for csampCollInA=', k
               call cerrorMsg(msg, 0)
         endif
        end
